import java.io.IOException;
import java.nio.file.FileSystem;
import java.nio.file.FileSystems;
import java.nio.file.Files;
import java.nio.file.Path;
import java.nio.file.attribute.FileAttribute;
import java.nio.file.attribute.PosixFilePermission;
import java.nio.file.attribute.PosixFilePermissions;
import java.util.Set;
import java.util.logging.Logger;

public class CreationDemo {
    private Logger logger = Logger.getLogger(Logger.GLOBAL_LOGGER_NAME);

    public CreationDemo() {
        FileSystem fileSystem = FileSystems.getDefault();

        try {
            // ファイルの作成
            Path foo = fileSystem.getPath("foo.txt");
            Files.createFile(foo);

            // ファイルの作成(パーミッション指定)
	    Path bar = fileSystem.getPath("bar.txt");

            Set<PosixFilePermission> filePermission 
                = PosixFilePermissions.fromString("r--r--r--");
            FileAttribute<Set<PosixFilePermission>> attribute 
                = PosixFilePermissions.asFileAttribute(filePermission);
            Files.createFile(bar, attribute);

            // ディレクトリの作成
            Path directory1 = fileSystem.getPath("dir1");
            Files.createDirectory(directory1);

            // 複数のディレクトリを作成
            Path directory2 = fileSystem.getPath("dir2", "dir3");
            Files.createDirectories(directory2);

            // リンクのターゲットの作成
            Path target = fileSystem.getPath("target.txt");
            if (!Files.exists(target)) {
                Files.createFile(target);
            }

            // ハードリンクの作成
            Path link = fileSystem.getPath("link.txt");
            Files.createLink(link, target);

            // シンボリックリンクの作成
            Path symbolicLink = fileSystem.getPath("symboliclink.txt");
            Files.createSymbolicLink(symbolicLink, target);
        } catch (IOException ex) {
            // 例外処理
            logger.throwing("CreationDemo", "<init>", ex);            
        }
    }

    public static void main(String[] args) {
        new CreationDemo();
    }
}